@@ -8,7 +8,7 @@ use IO::File;
 
 use vars qw/$VERSION/;
 
-$VERSION = 1.01;
+$VERSION = 1.02;
 
 sub new {
   my $class = shift;
@@ -126,12 +126,17 @@ sub _from_handle {
 
 return qw/Open hearts and empty minds/;
 
-__END__
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Text::CSV::Slurp - convert CSV into an array of hashes, or an array of
-hashes into CSV
+Text::CSV::Slurp - Text::CSV::Slurp - convert CSV into an array of hashes, or an array of hashes into CSV
+
+=head1 VERSION
+
+version 1.02
 
 =head1 SUMMARY
 
@@ -185,10 +190,15 @@ used as the keys for each of the hashes.
  close FH;
 
 Creates CSV from an arrayref of hashrefs and returns it as a string. All optional
-arguments are passed to L<Text::CSV> except for C<field_order>, which is used
-to determine the fields and order in which they appear in the CSV. For example:
+arguments are passed to L<Text::CSV> except for C<field_order>.
 
- my $csv = Text::CSV::Slurp->create( input => \@array_of_hashes, field_order => ['one','three','two'] );
+=head3 field_order
+
+C<field_order> which is used to determine the fields and order in which they 
+appear in the CSV. For example:
+
+ my $csv = Text::CSV::Slurp->create( input => \@array_of_hashes, 
+                                     field_order => ['one','three','two'] );
 
 If field_order is not supplied then the sorted keys of the first hash in the
 input are used instead.
@@ -219,4 +229,20 @@ L<Spreadsheet::Read>
 
 To Kyle Albritton for suggesting and testing the L<create> method
 
+=head1 AUTHOR
+
+BABF <babf@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by BABF.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+__END__
+
+# ABSTRACT: Text::CSV::Slurp - convert CSV into an array of hashes, or an array of hashes into CSV
+
